step

Attribute Macro step 

#[step]
Marks a function as a durable step.

The first parameter must be ctx: &Ctx. The macro wraps the function to check for saved output, execute if needed, and save the result.

#[durable::step]
async fn fetch_data(ctx: &Ctx, url: &str) -> Result<Data> {
    // ...
}